import { State } from "./state";
export declare class Fsm<NameType extends string | number | symbol = string, OpType extends string | number | symbol = string, BundleType = unknown> {
    private _states;
    private _startState?;
    get states(): Record<NameType, State<NameType, OpType, BundleType>>;
    addState(stateName: NameType, builder?: (this: Fsm<NameType, OpType, BundleType>, state: State<NameType, OpType, BundleType>) => void): Fsm<NameType, OpType, BundleType>;
    get startState(): State<NameType, OpType, BundleType> | undefined;
    createInstance(currentStateName?: NameType): FsmInstance<NameType, OpType, BundleType>;
    getState(stateName: NameType): State<NameType, OpType, BundleType>;
}
export declare class FsmInstance<NameType extends string | number | symbol = string, OpType extends string | number | symbol = string, BundleType = unknown> {
    private _fsm;
    private _stateName;
    private _bundle?;
    constructor(fsm: Fsm<NameType, OpType, BundleType>, currentStateName: NameType);
    bundle(): BundleType;
    bundle(arg: BundleType): FsmInstance<NameType, OpType, BundleType>;
    get states(): Record<NameType, State<NameType, OpType, BundleType>>;
    /**
     * set/get current state
     * @param {string} arg state name
     */
    get state(): State<NameType, OpType, BundleType>;
    get terminated(): boolean;
    perform<OnLeaveResult = unknown, OnEnterResult = unknown>(op: OpType, args?: unknown): Promise<{
        onLeaveResults: OnLeaveResult[];
        onEnterResults: OnEnterResult[];
    }>;
    getOps(): Promise<OpType[]>;
    getRelevantStates(): Promise<{
        operables: Set<NameType>;
        reachables: Set<NameType>;
    }>;
}
//# sourceMappingURL=fsm.d.ts.map